@@ -65,8 +65,8 @@ class Ui(object):
             self.config = self.load_config()
             log.debug('Loaded config.data file')
         except Exception as e:
-            log.warning('config file not found')
-            log.error(e, exc_info=True)
+            log.error(e)
+            log.warning('Will create new config file.')
             self.config = SetupConfig()
         self.nst = NotSoTuf(__name__, self.config)
         self.key_handler = KeyHandler()
@@ -76,6 +76,7 @@ class Ui(object):
 
     def update_mods(self, nst):
         self.key_handler.init_app(nst)
+        self.key_handler._add_filecrypt(self.file_crypt)
         self.package_handler.init_app(nst)
         self.uploader.init_app(nst)
         log.debug('Module updates complete')
@@ -180,7 +181,7 @@ class Ui(object):
 
     def private_key_copy(self):
         log.debug('Copied private key')
-        self.key_handler.copy_decrypted_private_key(self.file_crypt)
+        self.key_handler.copy_decrypted_private_key()
         msg = 'Private key decrypted. Press enter to continue'
         input_(format_msg(msg))
         self.keys()
@@ -477,7 +478,7 @@ def main():
             if update_check is True:
                 downloaded = client.download()
                 # Installing Update
-                if downloaded is True and client.up_to_date is False:
+                if downloaded is True:
                     client.install_restart()
 
             install_client_package()
