@@ -63,8 +63,6 @@ class FileDownloader(object):
 
                 False - Hash not verified
         """
-        # Downloads and verifies file against
-        # provided hash.
         self._download_to_memory()
         check = self._check_hash()
         if check:
@@ -100,11 +98,7 @@ class FileDownloader(object):
 
     @staticmethod
     def _best_block_size(elapsed_time, bytes):
-        """Returns best block size for current internet connection speed
-
-        Returns:
-            (int) Size of chuck to read
-        """
+        # Returns best block size for current internet connection speed
         new_min = max(bytes / 2.0, 1.0)
         new_max = min(max(bytes * 2.0, 1.0), 4194304)  # Do not surpass 4 MB
         if elapsed_time < 0.001:
@@ -117,8 +111,7 @@ class FileDownloader(object):
         return int(rate)
 
     def _download_to_memory(self):
-        """Downloads file to memory.  Keeps internal reference
-        """
+        # Downloads file to memory.  Keeps internal reference
         try:
             data = urllib2.urlopen(self.url)
         except urllib2.HTTPError:
@@ -157,24 +150,12 @@ class FileDownloader(object):
             log.debug('Block size: %s' % self.block_size)
 
     def _write_to_file(self):
-        """Writes download data to disk"""
-        # Writes file to disk
-        # TODO: Maybe add more verification here
-        # Suggestions always welcome
+        # Writes download data in memory to disk
         with open(self.filename, 'wb') as f:
             f.write(self.file_binary_data)
 
     def _check_hash(self):
-        """Checks hash of downloaded file.
-
-        Returns:
-            (bool) Meanings::
-
-                True - Hash verified
-
-                False - Hash not verified
-        """
-        # Simple hash returning function
+        # Checks hash of downloaded file
         if self.file_binary_data is None:
             return False
         log.debug('Checking file hash')
