@@ -92,13 +92,13 @@ class FileCrypt(object):
             log.warning('Cannot find encrypted file.')
 
     def del_folder_password(self):
-        username, app_name = self.make_username_appname()
+        username, app_name = self._make_username_appname()
         self._get_password()
         if self.password:
             log.warning('About to delete keyring password')
             keyring.delete_password(app_name, username)
             try:
-                del self.password
+                self.password = None
             except AttributeError:
                 self.password = None
 
@@ -107,16 +107,15 @@ class FileCrypt(object):
             self.password_timer = time.time() + float(sec)
 
     def _del_internal_password(self):
-        """Deletes user password once its not needed.
-        i.e. when the file been encrypted.
-        """
+        # Deletes user password once its not needed.
+        # i.e. when the file been encrypted or timer expired
         if self.password_timer < time.time():
             del self.password
             self.password = None
 
     def _get_password(self):
-        """Gets user passwod without echoing to console"""
-        username, app_name = self.make_username_appname()
+        # Gets user passwod without echoing to console
+        username, app_name = self._make_username_appname()
         app_name = 'NST-' + username
         log.info('Looking for keyring password')
         keyring_password = keyring.get_password(app_name, username)
@@ -138,9 +137,8 @@ class FileCrypt(object):
             sys.exit(0)
 
     def _set_password(self):
-        """Asks user for password twice, hashes password then sets password
-        in keyring
-        """
+        # Asks user for password twice, hashes password then sets
+        # password in keyring
         while 1:
             print('Create a new folder password.\n\n')
             password1 = getpass.getpass('Enter password\n--> ')
@@ -150,13 +148,12 @@ class FileCrypt(object):
             else:
                 msg = 'Passwords don\'t match.  Press enter to try again.'
                 raw_input(msg)
-        username, app_name = self.make_username_appname()
+        username, app_name = self._make_username_appname()
         hashed = pbkdf2.crypt(password1)
         keyring.set_password(app_name, username, hashed)
 
-    def make_username_appname(self):
-        """Makes username by base54 encoding current working directory.
-        """
+    def _make_username_appname(self):
+        # Makes username by base54 encoding current working directory.
         username = base64.b64encode(bytes(_cwd))
         app_name = 'NST-' + username
         return username, app_name
