@@ -54,9 +54,8 @@ else:
 
 
 class ChDir(object):
-    """Step into a directory temporarily. Then return to orignal
-    directory.
-    """
+    # Step into a directory temporarily. Then return to
+    # orignal directory.
     def __init__(self, path):
         self.old_dir = os.getcwd()
         self.new_dir = path
@@ -161,14 +160,6 @@ def rsa_verify(message, signature, key):
 
 
 def _get_package_hashes(filename):
-        """Get hash of provided file
-
-        Args:
-            package (str): File name to get hash for
-
-        Returns:
-            (str) md5 hash
-        """
         log.info('Getting package hashes')
         with open(filename, 'rb') as f:
             _hash = hashlib.md5(f.read()).hexdigest()
@@ -177,15 +168,7 @@ def _get_package_hashes(filename):
 
 
 def _remove_hidden_stuff_mac(files):
-        """Removes hidden files from file list
-
-        Args:
-            files (list): list of files
-
-        Returns:
-            (list) without .DS_Store and .AppleDouble
-        """
-        # Does what the name entails.
+        # Removes hidden files from file list
         # ToDo: Implement a better way of handling this if there is one
         # Any suggestions are warmly welcomed :)
         new_list = []
